@@ -103,7 +103,7 @@ class CommandContext:
         if ephemeral:
             message_body['data']['flags'] = 64
 
-        maybe_send = await self.__app.make_https_request(
+        maybe_send = await self.__app.make_http_request(
             "POST",
             f"webhooks/{self.__app.config['CLIENT_ID']}/{self.token}",
             payload=message_body
